==> soldat_extmod_api-0.0.2.tar.gz: soldat_extmod_api-0.0.2/soldat_extmod_api/interprocess_utils/game_addresses.py <==
addresses = {
    3712077237: { # 1.7.1.1 local build optimization off
            "GfxCreateTexture": 0x005178A4,
            "RenderInterface": 0x005F51C8,
            "GfxDrawSprite": 0x0051848C,
            "GfxTextColor": 0x00519C44,
            "GfxTextShadow": 0x00519C58,
            "SetFontStyle": 0x00605D24,
            "GfxTextScale": 0x00519C34,
            "GfxDrawText": 0x00519FAC,
            "ifacebyte": 0x3D,
            "Stbi_load_from_memory": 0x1470, # offset
            "camera_world_pos_x": 0x00907014,
            "camera_world_pos_y": 0x00907018,
            "cursor_screen_pos": 0x0062739C,
            "cursor_x_setter": 0x005741C0, # 2 nops to disable
            "cursor_y_setter": 0x005741CF,
            "game_width_half": 0x0061C588,
            "game_height_half": 0x0061C58C,
            "dxready": 0x0061C024,
            "CreateSprite": 0x0056FB0C,
            "CollisionCheck": 0x005C7238,
            "TransparencyUpdater": 0x005B4AD8,
            "ClientHandleSpecialMessage": 0x005E8C94,
            "LStrFromArray": 0x00404FB4,
            "FormKeyPress": 0x00589BD0,
            "player_base": 0x00907020,
            "player_sprite_base": 0x007A2710,
            "chat_show_flag": 0x0056F611,
            "current_map_name_length": 0x007B832C,
            "current_map_name": 0x007B832D,
            "own_id": 0x0069B82C,
            "ClientSendBullet": 0x005DCDFC,
            "client_tick_count": 0x00D2D44C,
            "CreateBullet": 0x00570490,
            "TSprite.Respawn": 0x005BB5B0,
            "dimousestate2": 0x00624B48,
            "tpolymap": 0x0061F78C,
            "TPolyMap.RayCast": 0x0060D59C,
            "Vector2": 0x004822E0,
            "TPolyMap.CollisionTest": 0x0060D2A4,
            "cam_restore_xptr": 0x0061E7C0,
            "cam_restore_yptr": 0x0061E60C,
            "cam_misc_1": 0x0056EC28,
            "cam_misc_2": 0x0056EC32,
            "cam_misc_3": 0x006042C6,
            "cam_misc_4": 0x006042D2,
            "cam_misc_5": 0x00604316,
            "cam_misc_6": 0x00604326,
            "cam_misc_7": 0x0060433C,
            "cam_misc_8": 0x00604934,
            "cam_misc_9": 0x00604942
        },
    1802620099: { # 1.7.1 https://static.soldat.pl/downloads/soldat171.zip
            "GfxCreateTexture": 0x0050919C,
            "RenderInterface": 0x005BD628,
            "GfxDrawSprite": 0x00509B0C,
            "GfxTextColor": 0x0050AEE4,
            "GfxTextShadow": 0x0050AEF4,
            "SetFontStyle": 0x005CD6B8,
            "GfxTextScale": 0x0050AED4,
            "GfxDrawText": 0x0050B1D8,
            "ifacebyte": 0x40,
            "Stbi_load_from_memory": 0x1470, # offset
            "camera_world_pos_x": 0x008CBFE8,
            "camera_world_pos_y": 0x008CBFEC,
            "cursor_screen_pos": 0x005EC370,
            "cursor_x_setter": 0x005492E5,
            "cursor_y_setter": 0x005492F4,
            "game_width_half": 0x005E45D0,
            "game_height_half": 0x005E4594,
            "dxready": 0x005E1714,
            "CreateSprite": 0x005458F4,
            "CollisionCheck": 0x00593934,
            "TransparencyUpdater": 0x00583C57,
            "FormKeyPress": 0x0055C7F0,
            "player_base": 0x008CBFF4,
            "player_size": 0xC5D0,
            "player_sprite_base": 0x007676E0,
            "player_sprite_size": 0x18BA,
            "chat_show_flag": 0x00545406,
            "TSprite.Respawn": 0x00589754,
            "dimousestate2": 0x005E9B24,
            "TPolyMap.RayCast": 0x005D437C,
            "TPolyMap.CollisionTest": 0x005D40F8,
            "Vector2": 0x00482974,
            "tpolymap": 0x0077D2FC,
            "cam_restore_xptr": 0x005E3E90,
            "cam_restore_yptr": 0x005E3CE0,
            "cam_misc_1": 0x00544BE8,
            "cam_misc_2": 0x00544BF2,
            "cam_misc_3": 0x005CC006,
            "cam_misc_4": 0x005CC012,
            "cam_misc_5": 0x005CC056,
            "cam_misc_6": 0x005CC066,
            "cam_misc_7": 0x005CC07C,
            "cam_misc_8": 0x005CC4F5,
            "cam_misc_9": 0x005CC503,
            "own_id": 0x00660800
        },
    3785736190: { # 1.7.1.1 https://static.soldat.pl/downloads/soldat1711.zip
            "GfxCreateTexture": 0x0050A73C,
            "RenderInterface": 0x005BF16C,
            "GfxDrawSprite": 0x0050AFD4,
            "GfxTextColor": 0x0050C2C0,
            "GfxTextShadow": 0x0050C2D0,
            "SetFontStyle": 0x005CF034,
            "GfxTextScale": 0x0050C2B0,
            "GfxDrawText": 0x0050C594,
            "ifacebyte": 0x40,
            "Stbi_load_from_memory": 0x1470, # offset
            "camera_world_pos_x": 0x008CF2D4,
            "camera_world_pos_y": 0x008CF2D8,
            "cursor_screen_pos": 0x005EF75C,
            "cursor_x_setter": 0x0054CC81,
            "cursor_y_setter": 0x0054CC90,
            "game_width_half": 0x005E3C6C,
            "game_height_half": 0x005E3C70,
            "dxready": 0x005E3718,
            "CreateSprite": 0x00549298,
            "CollisionCheck": 0x005972DC,
            "TransparencyUpdater": 0x0058770D,
            "FormKeyPress": 0x00560344,
            "player_base": 0x008CF2E0,
            "player_size": 0xC600,
            "player_sprite_base": 0x0076A9CC,
            "player_sprite_size": 0x18C0,
            "chat_show_flag": 0x00548DA9,
            "TSprite.Respawn": 0x0058D1F8,
            "dimousestate2": 0x005ECB24,
            "TPolyMap.RayCast": 0x005D5D7C,
            "TPolyMap.CollisionTest": 0x005D5AF8,
            "Vector2": 0x0048286C,
            "tpolymap": 0x007805E8,
            "cam_restore_xptr": 0x005E5F14,
            "cam_restore_yptr": 0x005E5D64,
            "cam_misc_1": 0x0054858B,
            "cam_misc_2": 0x00548595,
            "cam_misc_3": 0x005CD9FE,
            "cam_misc_4": 0x005CDA0A,
            "cam_misc_5": 0x005CDA4E,
            "cam_misc_6": 0x005CDA5E,
            "cam_misc_7": 0x005CDA74,
            "cam_misc_8": 0x005CDEC9,
            "cam_misc_9": 0x005CDED7,
            "own_id": 0x00663AE4
    }
}

==> soldat_extmod_api-0.0.5.tar.gz: soldat_extmod_api-0.0.5/soldat_extmod_api/interprocess_utils/game_addresses.py <==
addresses = {
    3712077237: { # 1.7.1.1 local build optimization off
            "GfxCreateTexture": 0x005178A4,
            "RenderInterface": 0x005F51C8,
            "GfxDrawSprite": 0x0051848C,
            "GfxTextColor": 0x00519C44,
            "GfxTextShadow": 0x00519C58,
            "SetFontStyle": 0x00605D24,
            "GfxTextScale": 0x00519C34,
            "GfxDrawText": 0x00519FAC,
            "ifacebyte": 0x3D,
            "Stbi_load_from_memory": 0x1470, # offset
            "camera_world_pos_x": 0x00907014,
            "camera_world_pos_y": 0x00907018,
            "cursor_screen_pos": 0x0062739C,
            "cursor_x_setter": 0x005741C0, # 2 nops to disable
            "cursor_y_setter": 0x005741CF,
            "game_width_half": 0x0061C588,
            "game_height_half": 0x0061C58C,
            "dxready": 0x0061C024,
            "CreateSprite": 0x0056FB0C,
            "CollisionCheck": 0x005C7238,
            "TransparencyUpdater": 0x005B4AD8,
            "ClientHandleSpecialMessage": 0x005E8C94,
            "LStrFromArray": 0x00404FB4,
            "FormKeyPress": 0x00589BD0,
            "player_base": 0x00907020,
            "player_sprite_base": 0x007A2710,
            "chat_show_flag": 0x0056F611,
            "current_map_name_length": 0x007B832C,
            "current_map_name": 0x007B832D,
            "own_id": 0x0069B82C,
            "ClientSendBullet": 0x005DCDFC,
            "client_tick_count": 0x00D2D44C,
            "CreateBullet": 0x00570490,
            "TSprite.Respawn": 0x005BB5B0,
            "dimousestate2": 0x00624B48,
            "tpolymap": 0x0061F78C,
            "TPolyMap.RayCast": 0x0060D59C,
            "Vector2": 0x004822E0,
            "TPolyMap.CollisionTest": 0x0060D2A4,
            "cam_restore_xptr": 0x0061E7C0,
            "cam_restore_yptr": 0x0061E60C,
            "cam_misc_1": 0x0056EC28,
            "cam_misc_2": 0x0056EC32,
            "cam_misc_3": 0x006042C6,
            "cam_misc_4": 0x006042D2,
            "cam_misc_5": 0x00604316,
            "cam_misc_6": 0x00604326,
            "cam_misc_7": 0x0060433C,
            "cam_misc_8": 0x00604934,
            "cam_misc_9": 0x00604942
        },
    1802620099: { # 1.7.1 https://static.soldat.pl/downloads/soldat171.zip
            "GfxCreateTexture": 0x0050919C,
            "RenderInterface": 0x005BD628,
            "GfxDrawSprite": 0x00509B0C,
            "GfxTextColor": 0x0050AEE4,
            "GfxTextShadow": 0x0050AEF4,
            "SetFontStyle": 0x005CD6B8,
            "GfxTextScale": 0x0050AED4,
            "GfxDrawText": 0x0050B1D8,
            "ifacebyte": 0x40,
            "Stbi_load_from_memory": 0x1470, # offset
            "camera_world_pos_x": 0x008CBFE8,
            "camera_world_pos_y": 0x008CBFEC,
            "cursor_screen_pos": 0x005EC370,
            "cursor_x_setter": 0x005492E5,
            "cursor_y_setter": 0x005492F4,
            "game_width_half": 0x005E45D0,
            "game_height_half": 0x005E4594,
            "dxready": 0x005E1714,
            "CreateSprite": 0x005458F4,
            "CollisionCheck": 0x00593934,
            "TransparencyUpdater": 0x00583C57,
            "FormKeyPress": 0x0055C7F0,
            "player_base": 0x008CBFF4,
            "player_size": 0xC5D0,
            "player_sprite_base": 0x007676E0,
            "player_sprite_size": 0x18BA,
            "chat_show_flag": 0x00545406,
            "current_map_name_length": 0x0077D300,
            "current_map_name": 0x0077D301,
            "TSprite.Respawn": 0x00589754,
            "dimousestate2": 0x005E9B24,
            "TPolyMap.RayCast": 0x005D437C,
            "TPolyMap.CollisionTest": 0x005D40F8,
            "Vector2": 0x00482974,
            "tpolymap": 0x0077D2FC,
            "cam_restore_xptr": 0x005E3E90,
            "cam_restore_yptr": 0x005E3CE0,
            "cam_misc_1": 0x00544BE8,
            "cam_misc_2": 0x00544BF2,
            "cam_misc_3": 0x005CC006,
            "cam_misc_4": 0x005CC012,
            "cam_misc_5": 0x005CC056,
            "cam_misc_6": 0x005CC066,
            "cam_misc_7": 0x005CC07C,
            "cam_misc_8": 0x005CC4F5,
            "cam_misc_9": 0x005CC503,
            "own_id": 0x00660800,
            "ExitToMenu": 0x0054ECCC
        },
    3785736190: { # 1.7.1.1 https://static.soldat.pl/downloads/soldat1711.zip
            "GfxCreateTexture": 0x0050A73C,
            "RenderInterface": 0x005BF16C,
            "GfxDrawSprite": 0x0050AFD4,
            "GfxTextColor": 0x0050C2C0,
            "GfxTextShadow": 0x0050C2D0,
            "SetFontStyle": 0x005CF034,
            "GfxTextScale": 0x0050C2B0,
            "GfxDrawText": 0x0050C594,
            "ifacebyte": 0x40,
            "Stbi_load_from_memory": 0x1470, # offset
            "camera_world_pos_x": 0x008CF2D4,
            "camera_world_pos_y": 0x008CF2D8,
            "cursor_screen_pos": 0x005EF75C,
            "cursor_x_setter": 0x0054CC81,
            "cursor_y_setter": 0x0054CC90,
            "game_width_half": 0x005E3C6C,
            "game_height_half": 0x005E3C70,
            "dxready": 0x005E3718,
            "CreateSprite": 0x00549298,
            "CollisionCheck": 0x005972DC,
            "TransparencyUpdater": 0x0058770D,
            "FormKeyPress": 0x00560344,
            "player_base": 0x008CF2E0,
            "player_size": 0xC600,
            "player_sprite_base": 0x0076A9CC,
            "player_sprite_size": 0x18C0,
            "chat_show_flag": 0x00548DA9,
            "current_map_name_length": 0x007805EC,
            "current_map_name": 0x007805ED,
            "TSprite.Respawn": 0x0058D1F8,
            "dimousestate2": 0x005ECB24,
            "TPolyMap.RayCast": 0x005D5D7C,
            "TPolyMap.CollisionTest": 0x005D5AF8,
            "Vector2": 0x0048286C,
            "tpolymap": 0x007805E8,
            "cam_restore_xptr": 0x005E5F14,
            "cam_restore_yptr": 0x005E5D64,
            "cam_misc_1": 0x0054858B,
            "cam_misc_2": 0x00548595,
            "cam_misc_3": 0x005CD9FE,
            "cam_misc_4": 0x005CDA0A,
            "cam_misc_5": 0x005CDA4E,
            "cam_misc_6": 0x005CDA5E,
            "cam_misc_7": 0x005CDA74,
            "cam_misc_8": 0x005CDEC9,
            "cam_misc_9": 0x005CDED7,
            "own_id": 0x00663AE4,
            "ExitToMenu": 0x00552668
    }
}
